# Welcome to xopr

[![Tests](https://github.com/englacial/xopr/actions/workflows/test.yml/badge.svg)](https://github.com/englacial/xopr/actions/workflows/test.yml)
[![Documentation](https://github.com/englacial/xopr/actions/workflows/docs.yml/badge.svg)](https://github.com/englacial/xopr/actions/workflows/docs.yml)
[![codecov](https://codecov.io/gh/englacial/xopr/branch/main/graph/badge.svg)](https://codecov.io/gh/englacial/xopr)
[![PyPI Version](https://img.shields.io/pypi/v/xopr.svg)](https://pypi.org/project/xopr/)
[![License](https://img.shields.io/github/license/englacial/xopr.svg)](LICENSE)

**Flight Coverage:** <!--ARCTIC_BADGE-->![Arctic](https://img.shields.io/badge/Arctic-847809%20km-00A4CC)<!--/ARCTIC_BADGE--> <!--ANTARCTIC_BADGE-->![Antarctic](https://img.shields.io/badge/Antarctic-592957%20km-FF6B35)<!--/ANTARCTIC_BADGE-->

<!--TOTAL_BADGE-->
![Total Data Ingest](https://progress-bar.xyz/41/?scale=100&title=Total%20Data%20Ingest&width=200&color=babaca&suffix=%25)
<!--/TOTAL_BADGE-->

*Data last updated: <!--LAST_UPDATED-->2026-01-22<!--/LAST_UPDATED-->*

**Try our code in binder:** [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/englacial/xopr/HEAD?urlpath=lab/tree/docs/notebooks)

**Documentation:** [![Jupyter Book Badge](https://img.shields.io/badge/jupyter-book-orange)](https://docs.englacial.org/xopr/)

**Contributor Code of Conduct:** [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](CODE_OF_CONDUCT.md)

xopr is a Python library designed to make accessing [Open Polar Radar's](https://ops.cresis.ku.edu/) data archives easy, scalable, and reproducible; see [here for current data availibility](https://docs.englacial.org/xopr/polar-maps/) within xopr..

**xopr is a work in progress! The API may evolve as we continue towards a stable 1.0 release.**

We welcome your feedback and contributions. If you run into problems or have ideas for how this could be better, please consider [opening an issue](https://github.com/englacial/xopr/issues/new/choose). We also welcome pull requests!

## Get started

Check out our [documentation](https://docs.englacial.org/xopr/) to get started. The documentation includes example notebooks to show you the core functions.

## License

This library was originally written by Thomas Teisberg and Shane Grigsby. It is open source and licensed under the [MIT License](./LICENSE).

<!-- Hidden tracking values for GitHub Action -->
<!-- ARCTIC_VALUE: 847809 -->
<!-- ANTARCTIC_VALUE: 592957 -->
<!-- TOTAL_VALUE: 1440766 -->
